@@ -613,7 +613,11 @@ def cal_performance(para_combination):
                 first_equity_value = df.loc[df['year'] == year].iloc[0].equity_value
             last_equity_value = df.loc[df['year'] == year].iloc[-1].equity_value
             yearly_return = (last_equity_value - first_equity_value) / first_equity_value
-            result_dict[f'{year}_return'] = int(yearly_return*100)
+            if np.isnan(yearly_return):
+                result_dict[f'{year}_return'] = 0 
+            else:
+                result_dict[f'{year}_return'] = int(yearly_return*100)
+
             first_equity_value = last_equity_value
 
 
