@@ -314,9 +314,10 @@ class Components:
         end_date_year = datetime.datetime.strptime(end_date, '%Y-%m-%d').year
         year_list = list(range(start_date_year, end_date_year + 1))
 
-        year_col1 = [dbc.Row([dbc.Col(style={'margin-left':'15px'}, width=3),
-                              dbc.Col('Year Count', style={'text-align': 'center', 'font-weight': 'bold', 'color':'yellow'},width=4),
-                              dbc.Col('Win Rate', style={'text-align': 'center', 'font-weight': 'bold', 'color':'yellow'},width=4)
+        year_col1 = [dbc.Row([dbc.Col(style={'margin-left':'15px'}, width=2),
+                              dbc.Col('Count', style={'text-align': 'center', 'font-weight': 'bold', 'color':'yellow'},width=3),
+                              dbc.Col('WinRate', style={'text-align': 'center', 'font-weight': 'bold', 'color':'yellow'},width=3),
+                              dbc.Col('Return', style={'text-align': 'center', 'font-weight': 'bold', 'color': 'yellow'}, width=3)
                               ], style={'font-size': '11px'})]
 
 
@@ -327,9 +328,16 @@ class Components:
                 # print(e)
                 win_rate = '-----'
 
-            year_col1.append(dbc.Row([dbc.Col(year_list[i],style={'margin-left':'15px'} ,width=3),
-                                      dbc.Col(df[str(year_list[i])], style={'text-align': 'center'} , width=4),
-                                      dbc.Col(win_rate, style={'text-align': 'center'} , width=4)]))
+            try:
+                year_return = "{:.0%}".format( int( float(df[f'{year_list[i]}_return']) )/100 )
+            except:
+                year_return = '-----'
+
+            year_col1.append(dbc.Row([dbc.Col(year_list[i],style={'margin-left':'15px'} ,width=2),
+                                      dbc.Col(df[str(year_list[i])], style={'text-align': 'center'} , width=3),
+                                      dbc.Col(win_rate, style={'text-align': 'center'} , width=3),
+                                      dbc.Col(year_return, style={'text-align': 'center'}, width=3),
+                                      ]))
         # Selected Equity Curve
         title = []
         for key in para_dict:
@@ -1261,12 +1269,15 @@ class Components:
         year_count = []
         year_count_col = []
         year_win_rate_col = []
+        year_return_col = []
         for year in year_list:
             year_col.append(html.Div(year))
             year_count.append(int(total_dict[f'{year}']))
             year_count_col.append(html.Div(int(total_dict[f'{year}'])))
             rate = total_dict[f'{year}_win_count']/total_dict[f'{year}']
             year_win_rate_col.append(html.Div( "{:.0%}".format(rate) ))
+            year_return = total_dict[f'{year}_return']
+            year_return_col.append(html.Div( "{:.0%}".format(year_return) ))
 
         cov = round(np.std(year_count) / np.mean(year_count), 2)
 
@@ -1320,14 +1331,16 @@ class Components:
 
             dbc.Row([
                 dbc.Col(width=3),
-                dbc.Col('Year Count', style={'color': 'Yellow', 'font-size': '15px'},width=5),
-                dbc.Col('Win Rate', style={'color': 'Yellow', 'font-size': '15px'},width=4),
+                dbc.Col('Count', style={'color': 'Yellow', 'font-size': '15px'},width=3),
+                dbc.Col('WinRate', style={'color': 'Yellow', 'font-size': '15px'},width=3),
+                dbc.Col('Return', style={'color': 'Yellow', 'font-size': '15px'}, width=3),
             ], style={'text-align': 'center'}),
 
             dbc.Row([
                 dbc.Col(year_col, width=3),
-                dbc.Col(year_count_col, width=5),
-                dbc.Col(year_win_rate_col, width=4),
+                dbc.Col(year_count_col, width=3),
+                dbc.Col(year_win_rate_col, width=3),
+                dbc.Col(year_return_col, width=3),
             ], style={'text-align': 'center'})
 
 
